summaryrefslogtreecommitdiffstats
path: root/digikam/libs/widgets/common/squeezedcombobox.h
diff options
context:
space:
mode:
Diffstat (limited to 'digikam/libs/widgets/common/squeezedcombobox.h')
-rw-r--r--digikam/libs/widgets/common/squeezedcombobox.h57
1 files changed, 29 insertions, 28 deletions
diff --git a/digikam/libs/widgets/common/squeezedcombobox.h b/digikam/libs/widgets/common/squeezedcombobox.h
index 242948c..c26792c 100644
--- a/digikam/libs/widgets/common/squeezedcombobox.h
+++ b/digikam/libs/widgets/common/squeezedcombobox.h
@@ -25,13 +25,13 @@
/** @file squeezedcombobox.h */
-#ifndef SQUEEZEDCOMBOBOX_H
-#define SQUEEZEDCOMBOBOX_H
+#ifndef STQUEEZEDCOMBOBOX_H
+#define STQUEEZEDCOMBOBOX_H
-// Qt includes.
+// TQt includes.
-#include <qcombobox.h>
-#include <qtooltip.h>
+#include <tqcombobox.h>
+#include <tqtooltip.h>
// Local includes.
@@ -44,7 +44,7 @@ class SqueezedComboBoxPriv;
/** @class SqueezedComboBox
*
* This widget is a QComboBox, but then a little bit
* different. It only shows the right part of the items
* depending on de size of the widget. When it is not
* possible to show the complete item, it will be shortened
@@ -53,18 +53,19 @@ class SqueezedComboBoxPriv;
* @image html squeezedcombobox.png "This is how it looks"
* @author Tom Albers
*/
-class DIGIKAM_EXPORT SqueezedComboBox : public QComboBox
+class DIGIKAM_EXPORT SqueezedComboBox : public TQComboBox
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor
* @param parent parent widget
* @param name name to give to the widget
*/
- SqueezedComboBox(QWidget *parent = 0, const char *name = 0 );
+ SqueezedComboBox(TQWidget *tqparent = 0, const char *name = 0 );
/**
* destructor
@@ -72,36 +73,36 @@ public:
virtual ~SqueezedComboBox();
/**
* This inserts a item to the list. See QComboBox::insertItem()
* for details. Please do not use QComboBox::insertItem() to this
* widget, as that will fail.
* @param newItem the original (long version) of the item which needs
* to be added to the combobox
* @param index the position in the widget.
*/
- void insertSqueezedItem(const QString& newItem, int index);
+ void insertSqueezedItem(const TQString& newItem, int index);
/**
* This inserts items to the list. See QComboBox::insertStringList()
* for details. Please do not use QComboBox::insertStringList() to this
* widget, as that will fail.
* @param newItems the originals (long version) of the items which needs
* to be added to the combobox
* @param index the position in the widget.
*/
- void insertSqueezedList(const QStringList& newItems, int index);
+ void insertSqueezedList(const TQStringList& newItems, int index);
/**
* This method returns the full text (not squeezed) of the currently
* highlighted item.
* @return full text of the highlighted item
*/
- QString itemHighlighted();
+ TQString itemHighlighted();
/**
* Sets the sizeHint() of this widget.
*/
- virtual QSize sizeHint() const;
+ virtual TQSize tqsizeHint() const;
private slots:
@@ -110,8 +111,8 @@ private slots:
private:
- void resizeEvent(QResizeEvent *);
- QString squeezeText(const QString& original);
+ void resizeEvent(TQResizeEvent *);
+ TQString squeezeText(const TQString& original);
private:
@@ -125,11 +126,11 @@ private:
* the tooltip will contain the full text and helps
* the user find the correct entry. It is automatically
* activated when starting a SqueezedComboBox. This is
* inherited from QToolTip
*
* @author Tom Albers
*/
-class SqueezedComboBoxTip : public QToolTip
+class SqueezedComboBoxTip : public TQToolTip
{
public:
@@ -140,18 +141,18 @@ public:
* t = new SqueezedComboBoxTip( this->listBox()->viewport(), this );
* @endcode
*
* @param parent parent widget (viewport)
* @param name parent widget
*/
- SqueezedComboBoxTip(QWidget *parent, SqueezedComboBox *name);
+ SqueezedComboBoxTip(TQWidget *tqparent, SqueezedComboBox *name);
protected:
/**
* Reimplemented version from QToolTip which shows the
* tooltip when needed.
* @param pos the point where the mouse currently is
*/
- void maybeTip(const QPoint& pos);
+ void maybeTip(const TQPoint& pos);
private:
@@ -160,4 +161,4 @@ private:
} // namespace Digikam
-#endif // SQUEEZEDCOMBOBOX_H
+#endif // STQUEEZEDCOMBOBOX_H
@@ -44,7 +44,7 @@ class SqueezedComboBoxPriv;
/** @class SqueezedComboBox
*
- * This widget is a QComboBox, but then a little bit
+ * This widget is a TQComboBox, but then a little bit
* different. It only shows the right part of the items
* depending on de size of the widget. When it is not
@@ -53,18 +53,19 @@ class SqueezedComboBoxPriv;
/**
* Constructor
- * @param parent parent widget
+ * @param tqparent tqparent widget
* @param name name to give to the widget
*/
@@ -72,36 +73,36 @@ public:
virtual ~SqueezedComboBox();
/**
- * This inserts a item to the list. See QComboBox::insertItem()
- * for details. Please do not use QComboBox::insertItem() to this
+ * This inserts a item to the list. See TQComboBox::insertItem()
+ * for details. Please do not use TQComboBox::insertItem() to this
* widget, as that will fail.
* @param newItem the original (long version) of the item which needs
@@ -72,36 +73,36 @@ public:
/**
- * This inserts items to the list. See QComboBox::insertStringList()
- * for details. Please do not use QComboBox::insertStringList() to this
+ * This inserts items to the list. See TQComboBox::insertStringList()
+ * for details. Please do not use TQComboBox::insertStringList() to this
* widget, as that will fail.
* @param newItems the originals (long version) of the items which needs
@@ -72,36 +73,36 @@ public:
/**
- * Sets the sizeHint() of this widget.
+ * Sets the tqsizeHint() of this widget.
*/
@@ -125,11 +126,11 @@ private:
* the user find the correct entry. It is automatically
* activated when starting a SqueezedComboBox. This is
- * inherited from QToolTip
+ * inherited from TQToolTip
*
* @author Tom Albers
@@ -140,18 +141,18 @@ public:
* @endcode
*
- * @param parent parent widget (viewport)
- * @param name parent widget
+ * @param tqparent tqparent widget (viewport)
+ * @param name tqparent widget
*/
@@ -140,18 +141,18 @@ public:
protected:
/**
- * Reimplemented version from QToolTip which shows the
+ * Reimplemented version from TQToolTip which shows the
* tooltip when needed.
* @param pos the point where the mouse currently is